/** The git errors which can be parsed from failed git commands. */
export declare enum GitError {
    GitNotFound = 0,
    SSHKeyAuditUnverified = 1,
    SSHAuthenticationFailed = 2,
    SSHPermissionDenied = 3,
    HTTPSAuthenticationFailed = 4,
    RemoteDisconnection = 5,
    HostDown = 6,
    RebaseConflicts = 7,
    MergeConflicts = 8,
    HTTPSRepositoryNotFound = 9,
    SSHRepositoryNotFound = 10,
    PushNotFastForward = 11,
    BranchDeletionFailed = 12,
    DefaultBranchDeletionFailed = 13,
    RevertConflicts = 14,
    EmptyRebasePatch = 15,
    NoMatchingRemoteBranch = 16,
    NothingToCommit = 17,
    NoSubmoduleMapping = 18,
    SubmoduleRepositoryDoesNotExist = 19,
    InvalidSubmoduleSHA = 20,
    LocalPermissionDenied = 21,
    InvalidMerge = 22,
    InvalidRebase = 23,
    NonFastForwardMergeIntoEmptyHead = 24,
    PatchDoesNotApply = 25,
    BranchAlreadyExists = 26,
    BadRevision = 27,
}
/** A mapping from regexes to the git error they identify. */
export declare const GitErrorRegexes: {
    "ERROR: ([\\s\\S]+?)\\n+\\[EPOLICYKEYAGE\\]\\n+fatal: Could not read from remote repository.": GitError;
    "fatal: Authentication failed": GitError;
    "fatal: Could not read from remote repository.": GitError;
    "The requested URL returned error: 403": GitError;
    "fatal: The remote end hung up unexpectedly": GitError;
    "fatal: unable to access '(.+)': Failed to connect to (.+): Host is down": GitError;
    "Failed to merge in the changes.": GitError;
    "(Merge conflict|Automatic merge failed; fix conflicts and then commit the result)": GitError;
    "fatal: repository '(.+)' not found": GitError;
    "ERROR: Repository not found": GitError;
    "\\((non-fast-forward|fetch first)\\)\nerror: failed to push some refs to '.*'": GitError;
    "error: unable to delete '(.+)': remote ref does not exist": GitError;
    "\\[remote rejected\\] (.+) \\(deletion of the current branch prohibited\\)": GitError;
    "error: could not revert .*\nhint: after resolving the conflicts, mark the corrected paths\nhint: with 'git add <paths>' or 'git rm <paths>'\nhint: and commit the result with 'git commit'": GitError;
    "Applying: .*\nNo changes - did you forget to use 'git add'\\?\nIf there is nothing left to stage, chances are that something else\n.*": GitError;
    "There are no candidates for (rebasing|merging) among the refs that you just fetched.\nGenerally this means that you provided a wildcard refspec which had no\nmatches on the remote end.": GitError;
    "nothing to commit": GitError;
    "No submodule mapping found in .gitmodules for path '(.+)'": GitError;
    "fatal: repository '(.+)' does not exist\nfatal: clone of '.+' into submodule path '(.+)' failed": GitError;
    "Fetched in submodule path '(.+)', but it did not contain (.+). Direct fetching of that commit failed.": GitError;
    "fatal: could not create work tree dir '(.+)'.*: Permission denied": GitError;
    "merge: (.+) - not something we can merge": GitError;
    "invalid upstream (.+)": GitError;
    "fatal: Non-fast-forward commit does not make sense into an empty head": GitError;
    "error: (.+): (patch does not apply|already exists in working directory)": GitError;
    "fatal: A branch named '(.+)' already exists.": GitError;
    "fatal: bad revision '(.*)'": GitError;
};
/** The exit code for 'Error No Entry' which could mean many things */
export declare const NotFoundExitCode: string;
