"use strict";
/** The git errors which can be parsed from failed git commands. */
(function (GitError) {
    GitError[GitError["GitNotFound"] = 0] = "GitNotFound";
    GitError[GitError["SSHKeyAuditUnverified"] = 1] = "SSHKeyAuditUnverified";
    GitError[GitError["SSHAuthenticationFailed"] = 2] = "SSHAuthenticationFailed";
    GitError[GitError["SSHPermissionDenied"] = 3] = "SSHPermissionDenied";
    GitError[GitError["HTTPSAuthenticationFailed"] = 4] = "HTTPSAuthenticationFailed";
    GitError[GitError["RemoteDisconnection"] = 5] = "RemoteDisconnection";
    GitError[GitError["HostDown"] = 6] = "HostDown";
    GitError[GitError["RebaseConflicts"] = 7] = "RebaseConflicts";
    GitError[GitError["MergeConflicts"] = 8] = "MergeConflicts";
    GitError[GitError["HTTPSRepositoryNotFound"] = 9] = "HTTPSRepositoryNotFound";
    GitError[GitError["SSHRepositoryNotFound"] = 10] = "SSHRepositoryNotFound";
    GitError[GitError["PushNotFastForward"] = 11] = "PushNotFastForward";
    GitError[GitError["BranchDeletionFailed"] = 12] = "BranchDeletionFailed";
    GitError[GitError["DefaultBranchDeletionFailed"] = 13] = "DefaultBranchDeletionFailed";
    GitError[GitError["RevertConflicts"] = 14] = "RevertConflicts";
    GitError[GitError["EmptyRebasePatch"] = 15] = "EmptyRebasePatch";
    GitError[GitError["NoMatchingRemoteBranch"] = 16] = "NoMatchingRemoteBranch";
    GitError[GitError["NothingToCommit"] = 17] = "NothingToCommit";
    GitError[GitError["NoSubmoduleMapping"] = 18] = "NoSubmoduleMapping";
    GitError[GitError["SubmoduleRepositoryDoesNotExist"] = 19] = "SubmoduleRepositoryDoesNotExist";
    GitError[GitError["InvalidSubmoduleSHA"] = 20] = "InvalidSubmoduleSHA";
    GitError[GitError["LocalPermissionDenied"] = 21] = "LocalPermissionDenied";
    GitError[GitError["InvalidMerge"] = 22] = "InvalidMerge";
    GitError[GitError["InvalidRebase"] = 23] = "InvalidRebase";
    GitError[GitError["NonFastForwardMergeIntoEmptyHead"] = 24] = "NonFastForwardMergeIntoEmptyHead";
    GitError[GitError["PatchDoesNotApply"] = 25] = "PatchDoesNotApply";
    GitError[GitError["BranchAlreadyExists"] = 26] = "BranchAlreadyExists";
    GitError[GitError["BadRevision"] = 27] = "BadRevision";
})(exports.GitError || (exports.GitError = {}));
var GitError = exports.GitError;
/** A mapping from regexes to the git error they identify. */
exports.GitErrorRegexes = {
    "ERROR: ([\\s\\S]+?)\\n+\\[EPOLICYKEYAGE\\]\\n+fatal: Could not read from remote repository.": GitError.SSHKeyAuditUnverified,
    "fatal: Authentication failed": GitError.SSHAuthenticationFailed,
    "fatal: Could not read from remote repository.": GitError.SSHPermissionDenied,
    "The requested URL returned error: 403": GitError.HTTPSAuthenticationFailed,
    "fatal: The remote end hung up unexpectedly": GitError.RemoteDisconnection,
    "fatal: unable to access '(.+)': Failed to connect to (.+): Host is down": GitError.HostDown,
    "Failed to merge in the changes.": GitError.RebaseConflicts,
    "(Merge conflict|Automatic merge failed; fix conflicts and then commit the result)": GitError.MergeConflicts,
    "fatal: repository '(.+)' not found": GitError.HTTPSRepositoryNotFound,
    "ERROR: Repository not found": GitError.SSHRepositoryNotFound,
    "\\((non-fast-forward|fetch first)\\)\nerror: failed to push some refs to '.*'": GitError.PushNotFastForward,
    "error: unable to delete '(.+)': remote ref does not exist": GitError.BranchDeletionFailed,
    "\\[remote rejected\\] (.+) \\(deletion of the current branch prohibited\\)": GitError.DefaultBranchDeletionFailed,
    "error: could not revert .*\nhint: after resolving the conflicts, mark the corrected paths\nhint: with 'git add <paths>' or 'git rm <paths>'\nhint: and commit the result with 'git commit'": GitError.RevertConflicts,
    "Applying: .*\nNo changes - did you forget to use 'git add'\\?\nIf there is nothing left to stage, chances are that something else\n.*": GitError.EmptyRebasePatch,
    "There are no candidates for (rebasing|merging) among the refs that you just fetched.\nGenerally this means that you provided a wildcard refspec which had no\nmatches on the remote end.": GitError.NoMatchingRemoteBranch,
    "nothing to commit": GitError.NothingToCommit,
    "No submodule mapping found in .gitmodules for path '(.+)'": GitError.NoSubmoduleMapping,
    "fatal: repository '(.+)' does not exist\nfatal: clone of '.+' into submodule path '(.+)' failed": GitError.SubmoduleRepositoryDoesNotExist,
    "Fetched in submodule path '(.+)', but it did not contain (.+). Direct fetching of that commit failed.": GitError.InvalidSubmoduleSHA,
    "fatal: could not create work tree dir '(.+)'.*: Permission denied": GitError.LocalPermissionDenied,
    "merge: (.+) - not something we can merge": GitError.InvalidMerge,
    "invalid upstream (.+)": GitError.InvalidRebase,
    "fatal: Non-fast-forward commit does not make sense into an empty head": GitError.NonFastForwardMergeIntoEmptyHead,
    "error: (.+): (patch does not apply|already exists in working directory)": GitError.PatchDoesNotApply,
    "fatal: A branch named '(.+)' already exists.": GitError.BranchAlreadyExists,
    "fatal: bad revision '(.*)'": GitError.BadRevision,
};
/** The exit code for 'Error No Entry' which could mean many things */
exports.NotFoundExitCode = "ENOENT";
//# sourceMappingURL=errors.js.map